@@ -1,6 +1,6 @@
 context("theme_publish")
 
-require(ggplot2)
+library(ggplot2)
 p <- ggplot(mtcars) +
   geom_point(aes(x = wt, y = mpg,
                  colour = factor(gear))) + facet_wrap( ~ am)
